@@ -1,17 +1,20 @@
+use crate::chain_actions::utils::now_date_time;
 use crate::wire_element::WireElement;
+use chrono::{DateTime, Datelike, Timelike, Utc};
 use hdk::prelude::*;
 use holo_hash::{AgentPubKey, EntryHashB64, HeaderHashB64};
 
 #[cfg(feature = "mock")]
 use ::mockall::automock;
 
+/// a struct which implements a [update_action](UpdateAction::update_action) method
+/// a method is used instead of a function so that it can be mocked to simplify unit testing
 #[derive(Debug, PartialEq, Clone)]
 pub struct UpdateAction {}
 #[cfg_attr(feature = "mock", automock)]
 impl UpdateAction {
     /// This will add an update to an entry.
-    /// It can also optionally send a signal of this event (by passing `send_signal` value `true`)
-    /// to all peers returned by the `get_peers` call given during the macro call to `crud!`
+    /// It can also optionally send a signal of this event to all peers supplied in `send_signal_to_peers`
     /// uses `ChainTopOrdering::Relaxed` such that multiple updates can be committed in parallel
     pub fn update_action<T, E, S>(
         &self,
@@ -19,6 +22,7 @@ impl UpdateAction {
         header_hash: HeaderHashB64,
         entry_type_id: String,
         send_signal_to_peers: Option<Vec<AgentPubKey>>,
+        add_time_path: Option<String>,
     ) -> ExternResult<WireElement<T>>
     where
         Entry: TryFrom<T, Error = E>,
@@ -38,6 +42,24 @@ impl UpdateAction {
             ),
         )?;
         let entry_address = hash_entry(entry.clone())?;
+        match add_time_path {
+            None => (),
+            Some(base_component) => {
+                // create a time_path
+                let date: DateTime<Utc> = now_date_time()?;
+
+                let time_path = crate::datetime_queries::utils::hour_path_from_date(
+                    base_component,
+                    date.year(),
+                    date.month(),
+                    date.day(),
+                    date.hour(),
+                );
+
+                time_path.ensure()?;
+                create_link(time_path.hash()?, entry_address.clone(), ())?;
+            }
+        }
         let wire_entry: WireElement<T> = WireElement {
             entry,
             header_hash,
