@@ -1,7 +1,7 @@
 use hdk::prelude::*;
 use holo_hash::{EntryHashB64, HeaderHashB64};
 
-use crate::retrieval::retrieval::EntryAndHash;
+use crate::retrieval::utils::EntryAndHash;
 
 #[doc = "This data structure will be very broadly useful and represents
           how an entry should be serialized along with what metadata to
